pub enum Error {
OddLength,
OutputTooSmall,
InvalidByte {
index: usize,
byte: u8,
},
}Expand description
Errors that can occur during hex encoding or decoding.
Variants
OddLength
The input length is odd; hex strings must have even number of bytes.
OutputTooSmall
The output buffer is too small.
InvalidByte
An invalid byte was encountered at the given position.